{% extends 'v1/base.html' %} {% load static %} {% block page_title %}Kubefacets
Login..{% endblock %} {% block js_files %} {% endblock %} {% block content %}

<div>
  <p>Oh no, it looks like you've stumbled upon a broken link!</p>
  <p>Don't worry, just hit the back button or head over to our homepage to continue exploring.</p>
</div>
{% endblock %}
