{% extends 'v1/base.html' %} {% load static %} {% block page_title %}Kubefacets
Login..{% endblock %} {% block js_files %} {% endblock %} {% block content %}

<div>
  <p>Oops! It appears that something went awry on our end. Our team is working diligently to resolve the issue. Please try again later.</p>
</div>
{% endblock %}
